@@ -16,7 +16,7 @@ from shapely import make_valid, reverse
 from shapely.geometry import LinearRing, LineString, MultiLineString, Point, Polygon
 from shapely.ops import linemerge
 
-from .errors import CrsError, InputError, SlopeError
+from .errors import CrsError, InputError, ShoalBreakError, SlopeError
 from .utils.clipping import clip_rays_by_polygon, remove_intersecting_lines
 from .utils.perpendicular import calculate_slopes
 from .utils.resolution import redistribute_vertices
@@ -297,19 +297,29 @@ class ShorelineAnalyzer:
         )
 
     def _build_intertidal(self):
-        end = LineString(
-            [
-                self.break_line.geometry.iloc[0].coords[-1],
-                self.shoal_line.geometry.iloc[0].coords[-1],
-            ]
-        )
+        try:
+            end = LineString(
+                [
+                    self.break_line.geometry.iloc[0].coords[-1],
+                    self.shoal_line.geometry.iloc[0].coords[-1],
+                ]
+            )
+        except IndexError:
+            raise ShoalBreakError(
+                "Couldn't get the end points for break or shoal lines!"
+            )
+        try:
+            start = LineString(
+                [
+                    self.shoal_line.geometry.iloc[0].coords[0],
+                    self.break_line.geometry.iloc[0].coords[0],
+                ]
+            )
+        except IndexError:
+            raise ShoalBreakError(
+                "Couldn't get the start points for shoal or break lines"
+            )
 
-        start = LineString(
-            [
-                self.shoal_line.geometry.iloc[0].coords[0],
-                self.break_line.geometry.iloc[0].coords[0],
-            ]
-        )
         lr = Polygon(
             LinearRing(
                 (
