@@ -21,3 +21,9 @@ class InputError(ShorelineError):
     """Generic input problems"""
 
     pass
+
+
+class ShoalBreakError(ShorelineError):
+    """Errors that occur during calculation of the intertidal slope"""
+
+    pass
